@@ -100,11 +100,11 @@ class OWGuardian(OWWidget):
         self.api_dlg = self.CredentialsDialog(self)
         self.api_dlg.accept(silent=True)
         gui.button(self.controlArea, self, 'The Guardian API Key',
-                   callback=self.api_dlg.exec_,
+                   callback=self.api_dlg.exec,
                    focusPolicy=Qt.NoFocus)
 
         # Query
-        query_box = gui.widgetBox(self.controlArea, 'Query', addSpace=True)
+        query_box = gui.widgetBox(self.controlArea, 'Query')
         self.query_box = QueryBox(query_box, self, self.recent_queries,
                                   callback=self.new_query_input)
 
